@@ -1,3 +1,5 @@
+from datetime import timedelta
+
 from django.apps import apps
 from django.conf import settings
 from django.core.exceptions import ObjectDoesNotExist
@@ -5,6 +7,8 @@ from django.db import models
 from django.utils import timezone
 from django.utils.functional import cached_property
 
+from .util import random_number_token
+
 
 class DeviceManager(models.Manager):
     """
@@ -186,6 +190,62 @@ class Device(models.Model):
         return False
 
 
+class SideChannelDevice(Device):
+    """
+    Abstract base model for a side-channel :term:`device` attached to a user.
+
+    This model implements token generation, verification and expiration, so the
+    concrete devices only have to implement delivery.
+
+    """
+    token = models.CharField(max_length=16, blank=True, null=True)
+    valid_until = models.DateTimeField(
+        default=timezone.now,
+        help_text="The timestamp of the moment of expiry of the saved token."
+    )
+
+    class Meta:
+        abstract = True
+
+    def generate_token(self, length=6, valid_secs=300, commit=True):
+        """
+        Generates a token of the specified length, then sets it on the model
+        and sets the expiration of the token on the model.
+
+        Pass 'commit=False' to avoid calling self.save().
+
+        :param int length: Number of decimal digits in the generated token.
+        :param int valid_secs: Amount of seconds the token should be valid.
+        :param bool commit: Whether to autosave the generated token.
+
+        """
+        self.token = random_number_token(length)
+        self.valid_until = timezone.now() + timedelta(seconds=valid_secs)
+        if commit:
+            self.save()
+
+    def verify_token(self, token):
+        """
+        Verifies a token by content and expiry.
+
+        On success, the token is cleared and the device saved.
+
+        :param string token: The OTP token provided by the user.
+        :rtype: bool
+
+        """
+        _now = timezone.now()
+
+        if (self.token is not None) and (token == self.token) and (_now < self.valid_until):
+            self.token = None
+            self.valid_until = _now
+            self.save()
+
+            return True
+        else:
+            return False
+
+
 class VerifyNotAllowed:
     """
     Constants that may be returned in the ``reason`` member of the extra
@@ -278,7 +338,7 @@ class ThrottlingMixin(models.Model):
     def throttling_enabled(self):
         return self.get_throttle_factor() > 0
 
-    def get_throttle_factor(self):
+    def get_throttle_factor(self):  # pragma: no cover
         raise NotImplementedError()
 
     class Meta:
