@@ -12,7 +12,10 @@ DEBUG = True
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
-        'NAME': ':memory:',
+        'NAME': project_path('db.sqlite3'),
+        'TEST': {
+            'NAME': ':memory:',
+        }
     }
 }
 
@@ -22,6 +25,7 @@ INSTALLED_APPS = [
     'django.contrib.contenttypes',
     'django.contrib.sessions',
     'django.contrib.messages',
+    'django.contrib.staticfiles',
 
     'django_otp',
     'django_otp.plugins.otp_email',
@@ -67,3 +71,7 @@ TEMPLATES = [
 SECRET_KEY = 'PWuluw4x48GkT7JDPzlDQsBJC8pjIIiqodW9MuMYcU315YEkGJL41i5qooJsg3Tt'
 
 ROOT_URLCONF = 'test_project.urls'
+
+STATIC_URL = '/static/'
+
+USE_TZ = True
